@@ -11,7 +11,7 @@
 #' @param Acoef1,Acoef2 Each one is a list object with K-by-K coefficient
 #' matrices of lagged endogenous variables. See help(Acoef_sh), or,
 #' help(Acoef).
-#' @return SSE value.
+#' @return An SSE value.
 #' @examples
 #' data(Canada, package = "vars")
 #' y <- diff(Canada)
@@ -23,16 +23,15 @@
 #' @export
 calcSSE_Acoef <- function(Acoef1, Acoef2) {
 
-	p1 = length(Acoef1)
-	p2 = length(Acoef2)
-	if (p1 != p2)  {
-	  warning("Input Acoef1 and Acoef2 have different orders..")
-	  return(-1)
-	}
-	sseValue <- 0
-	for (i in 1:p1) {
-	  sseValue = sseValue + sum((Acoef1[[i]] - Acoef2[[i]])^2)
-	}
-	return(sseValue)
+  p1 <- length(Acoef1)
+  p2 <- length(Acoef2)
+  if (p1 != p2)  {
+    warning("Input Acoef1 and Acoef2 have different orders..")
+    return(-1)
+  }
+  sseValue <- 0
+  for (i in 1:p1) {
+    sseValue <- sseValue + sum((Acoef1[[i]] - Acoef2[[i]])^2)
+  }
+  return(sseValue)
 }
-
